@@ -2,7 +2,7 @@ package Catmandu::Store;
 
 use Catmandu::Sane;
 
-our $VERSION = '1.0501';
+our $VERSION = '1.0502';
 
 use Hash::Util::FieldHash qw(fieldhash);
 use Sub::Quote qw(quote_sub);
@@ -19,10 +19,16 @@ has bags => (is => 'ro', default => sub {+{}},);
 
 has key_prefix => (is => 'lazy', default => sub {'_'},);
 
+has id_key => (is => 'lazy', alias => 'id_field');
+
 sub key_for {
     $_[0]->key_prefix . $_[1];
 }
 
+sub _build_id_key {
+    $_[0]->key_for('id');
+}
+
 {
     fieldhash my %bag_instances;
 
@@ -159,6 +165,12 @@ plugins or stores may add their own special keys.
     # this store will use the my_id key to hold id's
     Catmandu::Store::MyDB->new(key_prefix => 'my_')
 
+=item id_key
+
+Define a custom key to hold id's for all bags of this store. See C<key_prefix>
+for the default value. Also aliased as C<id_field>. Note that this can also be
+overriden on a per bag basis.
+
 =back
 
 =head1 METHODS
